(use-translation _ "alterator-network")

(include-as-is "/dialog/functions")

(on-apply (apply-network-settings))

(on-acc-leave
  (if *gns-was-changes* 'need-confirm))

(on-dbus 
  (if (and 
	(string=? interface "org.altlinux")
	(string=? dmember "network")
	(pair? args)
	(string=? (car args) "changed"))
    (update-general-network-settings)))

(define (gns-on-load-error reason) #f)

(define (get-gns)
  (woo-cache-ignore)
  (woo-first-command (woo-read "/simple_etcnet/general")))

(define *current-gns* (woo-catch get-gns gns-on-load-error))
(define (config-enabled?) (string=? (woo-get-option *current-gns* 'dhcp) "no"))

(define (update-general-network-settings)
  (woo-catch
    (lambda()
      (woo-cache-ignore)
      (set! *current-gns* 
	(woo-first-command (woo-read "/simple_etcnet/general")))
      ;we don't change content of the fields: only change "enabled" status
      (gateway enabled (config-enabled?))
      (dns1 enabled (config-enabled?))
      (dns2 enabled (config-enabled?)))
    gns-on-load-error))

(define (gns-on-apply-error reason)
  (if (or (string=? reason "wrong address")
	  (string=? reason "wrong name format"))
    (run-dialog `("/net/error" reason ,reason))
    (run-dialog '("/error")))
  #f)

(define (apply-network-settings)
  (if *gns-was-changes*
       (woo-catch
	 (lambda()
	   (with-splash-message
	     (lambda()
	       (splash-message (_ "restarting network ... "))
	       (woo-write "/simple_etcnet/general"
			  'hostname (hostname text)
			  'domainname (domainname text)
			  'gateway (gateway text)
			  'dns1 (dns1 text)
			  'dns2 (dns2 text))))
	   #t)
	 gns-on-apply-error)
       #t))

(define (check-can-dns2) 
  (dns2 readonly (empty-string? (dns1 text))))

(define *gns-was-changes* #f)

(define (update-fqdn)
  (next-button
    enabled (not (or (empty-string? (hostname text))
		     (empty-string? (domainname text)))))
  (fqdn text
	(string-append (hostname text) "." (domainname text))))

(vbox spacing 2 sizepolicy 'fixed
  (label (_ "General Network Settings") font bold-font)
  (hbox spacing 1
	(vbox
	  (label (_ "Fully Qualified Domain Name (FQDN):") height 3)
	  (label (_ "Host Name:") height 3)
	  (label (_ "Domain Name:") height 3))
	(vbox
	  (id 'fqdn (label (string-append (woo-get-option *current-gns* 'hostname)
					 "."
					 (woo-get-option *current-gns* 'domainname))
			     (relative-width 50 page)
			     height 3))
	  (id 'hostname (edit (woo-get-option *current-gns* 'hostname)
			      (on-change
				(set! *gns-was-changes* #t)
				(update-fqdn))
			      (relative-width 50 page)))
	  (id 'domainname (edit (woo-get-option *current-gns* 'domainname)
				(on-change
				  (set! *gns-was-changes* #t)
				  (update-fqdn))
				(relative-width 50 page)))))

  (hbox spacing 1
    (vbox
       (label (_ "Default route:") height 3)
      (label (_ "Primary DNS server:") height 3)
      (label (_ "Secondary DNS server:") height 3))
    (vbox
      (id 'gateway (edit (woo-get-option *current-gns* 'gateway)
			 (relative-width 50 page)
			 enabled (config-enabled?)
			 (on-change (set! *gns-was-changes* #t))))
      (id 'dns1 (edit (woo-get-option *current-gns* 'dns1)
		      (relative-width 50 page)
		      enabled (config-enabled?)
		      (on-change
			(set! *gns-was-changes* #t)
			(check-can-dns2))))
      (id 'dns2 (edit (woo-get-option *current-gns* 'dns2)
		      (relative-width 50 page)
		      readonly (empty-string? (woo-get-option *current-gns* 'dns1))
		      enabled (config-enabled?)
		      (on-change (set! *gns-was-changes* #t)))))))

